:mod:`ixmp`
***********

:doc:`Package documentation <ixmp:index>`

.. currentmodule:: genno.compat.ixmp

.. automodule:: genno.compat.ixmp
   :members:

.. automodule:: genno.compat.ixmp.computations
   :members:

.. automodule:: genno.compat.ixmp.reporter
   :members:

.. automodule:: genno.compat.ixmp.util
   :members:
